==> sky-6.x-1.0.tar.gz: sky/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language; ?>" xml:lang="<?php print $language; ?>">
<head>
<title><?php print $head_title; ?></title>
<?php print $head; ?><?php print $styles; ?><?php print $scripts; ?>
<script type="text/javascript"><?php /* Needed to avoid Flash of Unstyle Content in IE */ ?> </script>
<!--[if IE]><style type="text/css" media="all"> * html #IE img, * html #IE .png { position:relative;behavior: expression((this.runtimeStyle.behavior="none")&&(this.pngSet?this.pngSet=true:(this.nodeName == "IMG" && this.src.toLowerCase().indexOf('.png')>-1?(this.runtimeStyle.backgroundImage = "none", this.runtimeStyle.filter ="progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + this.src + "', sizingMethod='image')", this.src = "/<?php print path_to_theme(); ?>/images/transparent.gif"):(this.origBg = this.origBg? this.origBg :this.currentStyle.backgroundImage.toString().replace('url("','').replace('")',''), this.runtimeStyle.filter ="progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + this.origBg + "', sizingMethod='crop')", this.runtimeStyle.backgroundImage = "none")),this.pngSet=true) ); }</style><![endif]-->
</head>
<body class="<?php print $layout; ?>">
<!--[if IE 6]><div id="IE"><![endif]-->
<div id="wrapper">
  <?php if ($sky_title): ?>
  <span class="header_title"><?php print $sky_title; ?></span>
  <?php endif; ?>
  <div id="header">
    <?php if ($site_name): ?>
    <span class="site_name"> <a href="<?php print base_path(); ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a> </span>
    <?php endif; ?>
    <?php if ($logo): ?>
    <a href="<?php print base_path(); ?>" title="<?php print $site_name; ?>"><img src="<?php print $logo; ?>" alt="<?php if ($site_name): print $site_name;  endif; ?>" class="logo" /></a>
    <?php endif; ?>
    <?php if(variable_get('site_slogan', '')): ?>
    <span class="slogan"><?php print variable_get('site_slogan', ''); ?></span>
    <?php endif; ?>
    <div class="navigation"> <?php print theme('links', $primary_links); ?> </div>
  </div>
  <div class="container">
    <div id="page">
      <?php if ($secondary_links): ?>
      <div class="secondary_links"> <?php print theme('links', $secondary_links); ?></div>
      <?php endif; ?>
      <div id="content">
        <?php if ($breadcrumb): ?>
        <div class="breadcrumb"><?php print $breadcrumb; ?></div>
        <?php endif; ?>
        <?php if ($messages): ?>
        <?php print $messages; ?>
        <?php endif; ?>
        <?php if ($is_front && $mission): ?>
        <div class="mission"><?php print $mission; ?></div>
        <?php endif; ?>
        <?php if ($contenttop): ?>
        <div id="content_top"><?php print $contenttop; ?></div>
        <?php endif; ?>
        <?php if ($title): ?>
        <h1 class="title"><?php print $title; ?></h1>
        <?php endif; ?>
        <?php if ($help): ?>
        <div class="help"><?php print $help; ?></div>
        <?php endif; ?>
        <?php if ($tabs): ?>
        <?php print $tabs; ?>
        <?php endif; ?>
        <?php print $content; ?> <?php print $feed_icons; ?>
        <?php if ($contentbottom): ?>
        <div id="content_bottom"><?php print $contentbottom; ?></div>
        <?php endif; ?>
      </div>
    </div>
    <div id="sidebar"> <?php print $sidebar_left; ?> <?php print $sidebar_right; ?> </div>
  </div>
  <div class="push">&nbsp;</div>
</div>
<div id="footer"><?php print $contentfooter; ?> <?php print $footer_message; ?> <img src="/<?php print path_to_theme(); //IE6 Fix ?>/images/transparent.gif" style="height:2em;" alt="spacer" /> </div>
<!--[if IE 6]></div><![endif]-->
<?php print $closure; ?>
</body>
</html>

==> sky-6.x-1.1.tar.gz: sky/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language->language; ?>" xml:lang="<?php print $language->language; ?>">
<head>
<title><?php print $head_title; ?></title>
<?php print $head; ?><?php print $styles; ?><?php print $scripts; ?>
<script type="text/javascript"><?php /* Needed to avoid Flash of Unstyle Content in IE */ ?> </script>
<!--[if IE]><style type="text/css" media="all"> * html #IE img, * html #IE .png { position:relative;behavior: expression((this.runtimeStyle.behavior="none")&&(this.pngSet?this.pngSet=true:(this.nodeName == "IMG" && this.src.toLowerCase().indexOf('.png')>-1?(this.runtimeStyle.backgroundImage = "none", this.runtimeStyle.filter ="progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + this.src + "', sizingMethod='image')", this.src = "/<?php print path_to_theme(); ?>/images/transparent.gif"):(this.origBg = this.origBg? this.origBg :this.currentStyle.backgroundImage.toString().replace('url("','').replace('")',''), this.runtimeStyle.filter ="progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + this.origBg + "', sizingMethod='crop')", this.runtimeStyle.backgroundImage = "none")),this.pngSet=true) ); }</style><![endif]-->
</head>
<body class="<?php print $layout; ?>">
<!--[if IE 6]><div id="IE"><![endif]-->
<div id="wrapper">
  <?php if ($sky_title): ?>
  <span class="header_title"><?php print $sky_title; ?></span>
  <?php endif; ?>
  <div id="header">
    <?php if ($site_name): ?>
    <span class="site_name"> <a href="<?php print base_path(); ?>" title="<?php print $site_name; ?>"><?php print $site_name; ?></a> </span>
    <?php endif; ?>
    <?php if ($logo): ?>
    <a href="<?php print base_path(); ?>" title="<?php print $site_name; ?>"><img src="<?php print $logo; ?>" alt="<?php if ($site_name): print $site_name;  endif; ?>" class="logo" /></a>
    <?php endif; ?>
    <?php if(variable_get('site_slogan', '')): ?>
    <span class="slogan"><?php print variable_get('site_slogan', ''); ?></span>
    <?php endif; ?>
    <div class="navigation"> <?php print theme('links', $primary_links); ?> </div>
  </div>
  <div class="container">
    <div id="page">
      <?php if ($secondary_links): ?>
      <div class="secondary_links"> <?php print theme('links', $secondary_links); ?></div>
      <?php endif; ?>
      <div id="content">
        <?php if ($breadcrumb): ?>
        <div class="breadcrumb"><?php print $breadcrumb; ?></div>
        <?php endif; ?>
        <?php if ($messages): ?>
        <?php print $messages; ?>
        <?php endif; ?>
        <?php if (drupal_is_front_page() && $mission): ?>
        <div class="mission"><?php print $mission; ?></div>
        <?php endif; ?>
        <?php if ($contenttop): ?>
        <div id="content_top"><?php print $contenttop; ?></div>
        <?php endif; ?>
        <?php if ($title): ?>
        <h1 class="title"><?php print $title; ?></h1>
        <?php endif; ?>
        <?php if ($help): ?>
        <div class="help"><?php print $help; ?></div>
        <?php endif; ?>
        <?php if ($tabs): ?>
        <?php print $tabs; ?>
        <?php endif; ?>
        <?php print $content; ?> <?php print $feed_icons; ?>
        <?php if ($contentbottom): ?>
        <div id="content_bottom"><?php print $contentbottom; ?></div>
        <?php endif; ?>
      </div>
    </div>
    <div id="sidebar"> <?php print $left; ?> <?php print $right; ?> </div>
  </div>
  <div class="push">&nbsp;</div>
</div>
<div id="footer"><?php print $contentfooter; ?> <?php print $footer_message; ?> <img src="/<?php print path_to_theme(); //IE6 Fix ?>/images/transparent.gif" style="height:2em;" alt="spacer" /> </div>
<!--[if IE 6]></div><![endif]-->
<?php print $closure; ?>
</body>
</html>
